<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="kab">
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>Apli mode aktid</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation>Apli mode ddisaktid</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Ddisakti</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Akti</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Apli mode</translation>
    </message>
    <message>
        <source>Airplane mode settings</source>
        <translation>Ajusti apli mode</translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Apli mode</translation>
    </message>
</context>
<context>
    <name>BluetoothAdapterItem</name>
    <message>
        <source>My Devices</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Iɣewwaren n Bluetooth </translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Ddissud</translation>
    </message>
    <message>
        <source>Disable [Airplane Mode](#) first if you want to connect to a Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Sens</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Sermed</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Iɣewwaren n Bluetooth </translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 yettwaqqen</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Ala yetteqqen...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Yensa</translation>
    </message>
    <message>
        <source>Connected %1</source>
        <translation>Wassud %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>N wassud</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Dissud</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>BrightnessApplet</name>
    <message>
        <source>Brightness</source>
        <translation>Tliss</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>Ajusti ecran</translation>
    </message>
</context>
<context>
    <name>BrightnessItem</name>
    <message>
        <source>Display settings</source>
        <translation>Ajusti ecran</translation>
    </message>
</context>
<context>
    <name>BrightnessPlugin</name>
    <message>
        <source>Brightness</source>
        <translation>Tliss</translation>
    </message>
</context>
<context>
    <name>CWeekWidget</name>
    <message>
        <source>Sun</source>
        <translation>Sennat</translation>
    </message>
    <message>
        <source>Mon</source>
        <translation>Mounat</translation>
    </message>
    <message>
        <source>Tue</source>
        <translation>Tutut</translation>
    </message>
    <message>
        <source>Wed</source>
        <translation>Wedut</translation>
    </message>
    <message>
        <source>Thu</source>
        <translation>Tutut</translation>
    </message>
    <message>
        <source>Fri</source>
        <translation>Fritut</translation>
    </message>
    <message>
        <source>Sat</source>
        <translation>Sattut</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Rnu taneɣruft n unasiw</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Dat et temps</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>tarqen ddiwass 12</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>tarqen ddiwass 24</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Iɣewwaren n wakud</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>mzaztut l-kalendär</translation>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <source>Monday</source>
        <translation>Arim</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Aram</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Ahad</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Amhad</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Sem</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Sed</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Acer</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>arim</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>tuesday</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>wednesday</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>thursday</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>friday</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>saturday</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>sunday</translation>
    </message>
</context>
<context>
    <name>DeviceControlWidget</name>
    <message>
        <source>Other Devices</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DndModeItem</name>
    <message>
        <source>DND Mode</source>
        <translation>Mode DND</translation>
    </message>
    <message>
        <source>DND mode settings</source>
        <translation>t-sifarin DND</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>d-ksfis</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>d-ksba</translation>
    </message>
    <message>
        <source>DND mode enabled</source>
        <translation>Mode DND d-ksba</translation>
    </message>
    <message>
        <source>DND mode disabled</source>
        <translation>Mode DND d-ksfis</translation>
    </message>
</context>
<context>
    <name>DndModePlugin</name>
    <message>
        <source>DND Mode</source>
        <translation>Mode DND</translation>
    </message>
</context>
<context>
    <name>EyeComfortModeItem</name>
    <message>
        <source>Eye Comfort</source>
        <translation>T-sifarin t-komfort</translation>
    </message>
    <message>
        <source>Eye comfort enabled</source>
        <translation>T-sifarin t-komfort d-ksba</translation>
    </message>
    <message>
        <source>Eye comfort disabled</source>
        <translation>T-sifarin t-komfort d-ksfis</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>t-sifarin t-disk</translation>
    </message>
    <message>
        <source>Eye comfort</source>
        <translation>T-komfort</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Aan</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Fas</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Agligh</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Adark</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Aautu</translation>
    </message>
    <message>
        <source>Disable eye comfort</source>
        <translation>Dinseb lqalit lqalit</translation>
    </message>
    <message>
        <source>Enable eye comfort</source>
        <translation>Wassil lqalit lqalit</translation>
    </message>
    <message>
        <source>Display Settings</source>
        <translation>Sittim lqalit</translation>
    </message>
    <message>
        <source>Theme: Light</source>
        <translation>Tema: Agligh</translation>
    </message>
    <message>
        <source>Theme: Dark</source>
        <translation>Tema: Adark</translation>
    </message>
    <message>
        <source>Theme: Auto</source>
        <translation>Tema: Aautu</translation>
    </message>
    <message>
        <source>Visual effect</source>
        <translation>Efftakat vizual</translation>
    </message>
</context>
<context>
    <name>EyeComfortmodeApplet</name>
    <message>
        <source>Light</source>
        <translation>Agligh</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Adark</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Aautu</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
</context>
<context>
    <name>NotificationPlugin</name>
    <message>
        <source>No messages</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Notification settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Notifications</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Turn off DND mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Turn on DND mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Notification</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Onboard</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Iɣewwaren</translation>
    </message>
</context>
<context>
    <name>PerformanceModeController</name>
    <message>
        <source>High Performance</source>
        <translation>Performans hig</translation>
    </message>
    <message>
        <source>Balanced</source>
        <translation>Balanced</translation>
    </message>
    <message>
        <source>Power Saver</source>
        <translation>Saver wass</translation>
    </message>
    <message>
        <source>Balance Performance</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PowerApplet</name>
    <message>
        <source>Power</source>
        <translation>Wass</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power settings</source>
        <translation>Tetsekkar wass</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Capaciti %1, %2 min gudug</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Capaciti %1, %2 hr %3 min gudug</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Charging %1, %2 min gudug tilli full</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Charging %1, %2 hr %3 min gudug tilli full</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Capaciti %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Charging %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Capasité %1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Capasité %1, complètement chargé</translation>
    </message>
    <message>
        <source>Capacity %1, not charging</source>
        <translation>Capasité %1, ne charge pas</translation>
    </message>
    <message>
        <source>Battery</source>
        <translation>Batteri</translation>
    </message>
    <message>
        <source>Charging, calculating estimated charging time</source>
        <translation>Charge, calculant le temps de charge estimé</translation>
    </message>
    <message>
        <source>Calculating remaining usage time</source>
        <translation>Calculant le temps de fonctionnement restant</translation>
    </message>
    <message>
        <source>%1 min remaining</source>
        <translation>&apos;%1 min restantes&apos;, </translation>
    </message>
    <message>
        <source>%1 hr %2 min remaining</source>
        <translation>&apos;%1 hr %2 min restantes&apos;, </translation>
    </message>
    <message>
        <source>Not charging</source>
        <translation>Ne charge pas</translation>
    </message>
    <message>
        <source>Fully charged</source>
        <translation>Complètement chargé</translation>
    </message>
    <message>
        <source>Charging, %1 min until full</source>
        <translation>Charge, %1 min restantes pour être pleine</translation>
    </message>
    <message>
        <source>Charging, %1 hr %2 min until full</source>
        <translation>Charge, %1 hr %2 min restantes pour être pleine</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr remaining</source>
        <translation>Capasité %1, %2 hr restantes</translation>
    </message>
    <message>
        <source>%1 hr remaining</source>
        <translation>&apos;%1 hr restantes&apos;, </translation>
    </message>
    <message>
        <source>Charging %1, %2 hr until full</source>
        <translation>Charge %1, %2 hr restantes pour être pleine</translation>
    </message>
    <message>
        <source>Charging, %1 hr until full</source>
        <translation>Charge, %1 hr restantes pour être pleine</translation>
    </message>
</context>
<context>
    <name>PowerStatusWidget</name>
    <message>
        <source>Power settings</source>
        <translation>Paramètres d&apos;énergie</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Music</source>
        <translation>Muzik</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Inconnu</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Shut down</source>
        <translation>Sens</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Seḥbes</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Ibber</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Sekkeṛ</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Ffeɣ</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Aitamalat awal</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Ales asekker</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>Tawersan iwlus iwer awal</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>Tawersan iwlus iwer awal</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Awal</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Tawersan uset</translation>
    </message>
</context>
<context>
    <name>SidebarCalendarWidget</name>
    <message>
        <source>Today</source>
        <translation>Iyaz</translation>
    </message>
    <message>
        <source>Lunar</source>
        <translation>Lunar</translation>
    </message>
    <message>
        <source>y</source>
        <translation>y</translation>
    </message>
    <message>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <source>d</source>
        <translation>d</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Iwaz</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Itaz</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Itraz</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Itraz</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Ifriz</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Imsaz</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Isaz</translation>
    </message>
    <message>
        <source>Jan</source>
        <translation>Yan</translation>
    </message>
    <message>
        <source>Feb</source>
        <translation>Fev</translation>
    </message>
    <message>
        <source>Mar</source>
        <translation>Mars</translation>
    </message>
    <message>
        <source>Apr</source>
        <translation>April</translation>
    </message>
    <message>
        <source>May</source>
        <translation>Mai</translation>
    </message>
    <message>
        <source>Jun</source>
        <translation>Jun</translation>
    </message>
    <message>
        <source>Jul</source>
        <translation>Jul</translation>
    </message>
    <message>
        <source>Aug</source>
        <translation>Auw</translation>
    </message>
    <message>
        <source>Sept</source>
        <translation>Sipt</translation>
    </message>
    <message>
        <source>Oct</source>
        <translation>Tut</translation>
    </message>
    <message>
        <source>Nov</source>
        <translation>Nuv</translation>
    </message>
    <message>
        <source>Dec</source>
        <translation>Dek</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>Ammazghu tefeddan</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>mouad</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>tutad</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>wedd</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>touad</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>frad</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>sautad</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>soud</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Volume</source>
        <translation>Amuz</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Sifad</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Gnawass amuz</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Imesli</translation>
    </message>
</context>
<context>
    <name>SoundView</name>
    <message>
        <source>Unmute</source>
        <translation>Amuz</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Sifad</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Gnawass amuz</translation>
    </message>
    <message>
        <source>No output devices</source>
        <translation>Chwi n sifad</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Amuz %1</translation>
    </message>
</context>
</TS>